==> scons_4.0.1+dfsg.orig.tar.xz: scons-4.0.1+dfsg/test/Removed/debug-tree.py <==
#!/usr/bin/env python
#
# __COPYRIGHT__
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"

"""
Test that the --debug=tree option fails with expected exception
Check command-line, SCONSFLAGS and interactive
"""

import os

import TestSCons

test = TestSCons.TestSCons()


test.write('SConstruct', "")

expect = r"""usage: scons [OPTION] [TARGET] ...

SCons Error: `tree' is not a valid debug option type ; please use --tree=all instead
"""

test.run(arguments='-Q --debug=tree', status=2, stderr=expect)

os.environ['SCONSFLAGS'] = '--debug=tree'
test.run(arguments="-H", status=2, stderr=expect)


# moved test from test/Interactive/tree.py
scons = test.start(arguments = '-Q --interactive')
scons.send("build --debug=tree\n")
test.finish(scons, status=2, stderr=expect)


test.pass_test()

# Local Variables:
# tab-width:4
# indent-tabs-mode:nil
# End:
# vim: set expandtab tabstop=4 shiftwidth=4:

==> scons_4.4.0+dfsg.orig.tar.xz: scons-4.4.0/test/Removed/debug-tree.py <==
#!/usr/bin/env python
#
# MIT License
#
# Copyright The SCons Foundation
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
Test that the --debug=tree option fails with expected exception
Check command-line, SCONSFLAGS and interactive
"""

import os

import TestSCons

test = TestSCons.TestSCons()


test.write('SConstruct', "")

expect = r"""usage: scons [OPTIONS] [VARIABLES] [TARGETS]

SCons Error: `tree' is not a valid debug option type ; please use --tree=all instead
"""

test.run(arguments='-Q --debug=tree', status=2, stderr=expect)

os.environ['SCONSFLAGS'] = '--debug=tree'
test.run(arguments="-H", status=2, stderr=expect)


# moved test from test/Interactive/tree.py
scons = test.start(arguments = '-Q --interactive')
scons.send("build --debug=tree\n")
test.finish(scons, status=2, stderr=expect)


test.pass_test()

# Local Variables:
# tab-width:4
# indent-tabs-mode:nil
# End:
# vim: set expandtab tabstop=4 shiftwidth=4:
